<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package VT Blogging Pro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function vt_blogging_pro_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}
	
	$sidebar_position = get_theme_mod( 'sidebar_position' );

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) || $sidebar_position == 'none' ) {

		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'vt_blogging_pro_body_classes' );

/**
 * Add container class.
 */
if( ! function_exists( 'vt_blogging_pro_container_class' ) ) {

	function vt_blogging_pro_container_class() {

		$content_class = 'content-area clear';

		$sidebar_position = get_theme_mod( 'sidebar_position' );

		if( $sidebar_position == 'left' ) {

			$content_class .= ' col-right'; 
		}

		echo esc_attr( $content_class );
	}
}

/**
 * Add custom class for sidebar.
 */
if( ! function_exists( 'vt_blogging_pro_sidebar_class' ) ) {

	function vt_blogging_pro_sidebar_class() {

		$sidebar_class = 'widget-area sidebar';

		$sidebar_position = get_theme_mod( 'sidebar_position' );

		if( $sidebar_position == 'left' ) {

			$sidebar_class .= ' col-left'; 
		}

		echo esc_attr( $sidebar_class );
	}
}

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function vt_blogging_pro_pingback_header() {
	
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
	}
}
add_action( 'wp_head', 'vt_blogging_pro_pingback_header' );

// sticky-header
function vt_blogging_pro_sticky_header() {
	
	if (get_theme_mod('sticky-header', 1) == 1){
		
?>
	<script src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/js/sticky-header.js"></script>
	
<?php
}}
add_action('wp_footer', 'vt_blogging_pro_sticky_header');

// Animation
function vt_blogging_pro_animate_enable() {
	
	if (get_theme_mod('animate_enable', 1) == 1){
		
?>
	<script>AOS.init();</script>
	
<?php
}}
add_action('wp_footer', 'vt_blogging_pro_animate_enable');

// Url Encode
function vt_blogging_pro_url_encode($title){
	
    $title = html_entity_decode($title);
    $title = urlencode($title);
    return $title;
	
}

/**
 * Filter the except length characters.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
if ( ! function_exists( 'vt_blogging_pro_custom_excerpt_length' ) ) :

function vt_blogging_pro_custom_excerpt_length( $length ) {
	
    return get_theme_mod('entry-excerpt-length', '38');
	
}
add_filter( 'excerpt_length', 'vt_blogging_pro_custom_excerpt_length', 999 );

endif;

/**
 * Customize excerpt more.
 */
if ( ! function_exists( 'vt_blogging_pro_excerpt_more' ) ) :

function vt_blogging_pro_excerpt_more( $more ) {
	
   return '&hellip;';
}
add_filter( 'excerpt_more', 'vt_blogging_pro_excerpt_more' );

endif;

/**
 * Custom excerpt max charlength
 */
function vt_blogging_pro_the_excerpt_max_charlength($charlength)
{
	$excerpt = get_the_excerpt();
	$charlength++;

	if ( mb_strlen( $excerpt ) > $charlength ) {
		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
		$exwords = explode( ' ', $subex );
		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
		if ( $excut < 0 ) {
			echo mb_substr( $subex, 0, $excut );
		} else {
			echo $subex;
		}
		echo '&nbsp;...';
	} else {
		echo $excerpt;
	}
}

/**
 * Display the first (single) category of post.
 */
if ( ! function_exists( 'vt_blogging_pro_first_category' ) ) :
function vt_blogging_pro_first_category() {
	
    $category = get_the_category();
    if ($category) {
      echo '<a href="' . get_category_link( $category[0]->term_id ) . '" title="' . sprintf( __( "View all posts in %s", 'vt-blogging-pro' ), $category[0]->name ) . '" ' . '>' . $category[0]->name.'</a> ';
    }
	
}
endif;

/**
 * Adjust is_home query if vt-blog-cats is set
 */
function vt_blogging_pro_set_blog_queries( $query ) {
	
    $blog_query_set = '';
    if ( get_theme_mod( 'vt-blog-cats' ) ) {
        $blog_query_set = get_theme_mod( 'vt-blog-cats' );
    }

    if ( $blog_query_set ) {
        // do not alter the query on wp-admin pages and only alter it if it's the main query
        if ( !is_admin() && $query->is_main_query() ){
            if ( is_home() ){
                $query->set( 'cat', $blog_query_set );
            }
        }
    }
}
add_action( 'pre_get_posts', 'vt_blogging_pro_set_blog_queries' );

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
if ( ! function_exists( 'vt_blogging_pro_categorized_blog' ) ) :

function vt_blogging_pro_categorized_blog() {
	
    if ( false === ( $all_the_cool_cats = get_transient( 'vt_blogging_pro_categories' ) ) ) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories( array(
            'fields'     => 'ids',
            'hide_empty' => 1,
            // We only need to know if there is more than one category.
            'number'     => 2,
        ) );

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count( $all_the_cool_cats );

        set_transient( 'vt_blogging_pro_categories', $all_the_cool_cats );
    }

    if ( $all_the_cool_cats > 1 ) {
        // This blog has more than 1 category so vt_blogging_pro_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so vt_blogging_pro_categorized_blog should return false.
        return false;
    }
}

endif;

// Display custom categories
function vt_blogging_pro_display_custom_categories( $post_id, $limit = 5 ) {
	
    $cats = array(); $i = 0; $post_id = (int)$post_id;
    foreach( wp_get_post_categories($post_id) as $c )
    {
        $i++;
        if ( $i <= $limit )
        {
            $cat = get_category($c);
            array_push($cats, '<a href="'.(get_category_link($cat->term_id)).'">'.esc_html($cat->name).'</a>');
        }
        
        if ( $i == $limit + 1 ) {
            array_push($cats, '...');
        }
    }
    
    if ( sizeOf($cats) > 0 ) {
    	$post_categories = implode(', ',$cats);
    } else {
    	$post_categories = "Not Assigned";
    }
    
    return $post_categories;
}

/**
 * Register a custom Post Categories ID column
 */
function vt_blogging_pro_edit_cat_columns( $vt_blogging_pro_cat_columns ) {
	
    $vt_blogging_pro_cat_in = array( 'cat_id' => 'Category ID <span class="cat_id_note">For the Default Slider</span>' );
    $vt_blogging_pro_cat_columns = vt_blogging_pro_cat_columns_array_push_after( $vt_blogging_pro_cat_columns, $vt_blogging_pro_cat_in, 0 );
    return $vt_blogging_pro_cat_columns;
	
}
add_filter( 'manage_edit-category_columns', 'vt_blogging_pro_edit_cat_columns' );

// Print the ID column
function vt_blogging_pro_cat_custom_columns( $value, $name, $cat_id ) {
	
    if( 'cat_id' == $name )
        echo $cat_id;
}
add_filter( 'manage_category_custom_column', 'vt_blogging_pro_cat_custom_columns', 10, 3 );

// Insert an element at the beginning of the array
function vt_blogging_pro_cat_columns_array_push_after( $src, $vt_blogging_pro_cat_in, $pos ) {
	
    if ( is_int( $pos ) ) {
        $R = array_merge( array_slice( $src, 0, $pos + 1 ), $vt_blogging_pro_cat_in, array_slice( $src, $pos + 1 ) );
    } else {
        foreach ( $src as $k => $v ) {
            $R[$k] = $v;
            if ( $k == $pos )
                $R = array_merge( $R, $vt_blogging_pro_cat_in );
        }
    }
    return $R;
}

/**
 * Site branding
 */
function vt_blogging_pro_header(){ ?>

	<div class="site-branding">
		<?php if ( has_custom_logo() ) { ?>
			<?php if ( is_front_page() || is_home() || is_404() ) { ?>
				<h1 id="logo" class="image-logo" itemprop="headline">
					<span class="helper"></span>
					<?php the_custom_logo(); ?>
				</h1><!-- END #logo -->
				<?php } else { ?>
				<h2 id="logo" class="image-logo" itemprop="headline">
					<span class="helper"></span>
					<?php the_custom_logo(); ?>
				</h2><!-- END #logo -->
			<?php } ?>
		<?php } else { ?>
			<?php if ( is_front_page() || is_home() || is_404() ) { ?>
				<h1 id="logo" class="site-title" itemprop="headline">
					<a href="<?php echo esc_url( home_url() ); ?>"><?php bloginfo( 'name' ); ?></a>
				</h1><!-- END #logo -->
				<?php if(!get_theme_mod('disable_site_desc')) : ?><h2 class="site-description"><?php bloginfo( 'description' ); ?></h2><?php endif; ?>
			<?php } else { ?>
				<h2 id="logo" class="site-title" itemprop="headline">
					<a href="<?php echo esc_url( home_url() ); ?>"><?php bloginfo( 'name' ); ?></a>
				</h2><!-- END #logo -->
				<?php if(!get_theme_mod('disable_site_desc')) : ?><h3 class="site-description"><?php bloginfo( 'description' ); ?></h3><?php endif; ?>
			<?php } ?>
		<?php } ?>
	</div><!-- .site-branding -->
			
	<?php

}
add_action('vt_blogging_pro_header','vt_blogging_pro_header',20);

/**
 * Menu Nav
 */
function vt_blogging_pro_menu(){ ?>

	<nav id="primary-nav" class="main-navigation" role="navigation" itemscope itemtype="http://schema.org/SiteNavigationElement">

		<?php 
			if ( has_nav_menu( 'primary' ) ) {
				wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu', 'menu_class' => 'sf-menu' ) );
			} else {
		?>

		<ul class="sf-menu">
		  <?php if ( current_user_can( 'edit_theme_options' ) ) { ?>
			<li><?php printf(
				/* translators: %s: link to nav-menus */
				__( '<a href="%s">Add menu for theme location: Primary Menu.</a>', 'vt-blogging-pro' ), esc_url( admin_url( 'nav-menus.php' ) ) ); ?>
			</li>
		<?php } ?>
		</ul><!-- .sf-menu -->

		<?php } ?>

	</nav><!-- #primary-nav -->

	<?php

}
add_action('vt_blogging_pro_menu','vt_blogging_pro_menu',20);

/**
 * Get Post Views.
 */
if ( ! function_exists( 'vt_blogging_pro_get_post_views' ) ) :

function vt_blogging_pro_get_post_views($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return '<span class="view-count">0</span> View';
    }
    if ($count > 1000) {
        return '<span class="view-count"><i class="fa fa-eye"></i>' . round ( $count / 1000 ,1 ).'K</span>';
    } else {
		return '<span class="view-count"><i class="fa fa-eye"></i>' . number_format($count) . '</span>';
    }
}

endif;

/**
 * Set Post Views.
 */
if ( ! function_exists( 'vt_blogging_pro_set_post_views' ) ) :

function vt_blogging_pro_set_post_views($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

endif;

// Single post advertisement - Before content.
function vt_blogging_pro_single_ad_before( $content ) {
	
	$ad = get_theme_mod('vt_blogging_pro_ad_single_before');

	if ( get_theme_mod('vt_blogging_pro_ad_single_before', true) ) {
	  if ( is_single() ) {
		
		$content = '<div class="sponsor top" itemscope itemtype="http://schema.org/WPAdBlock">
		<meta itemprop="name" content="Advertise Block" />
		<meta itemprop="description" content="Advertisement"/>
		' . $ad . '</div>' . $content;
		
	  } else {
		$content;
	  }
	}

	return $content;

}
add_action( 'the_content', 'vt_blogging_pro_single_ad_before' );

// Single post advertisement - After content.
function vt_blogging_pro_single_ad_after( $content ) {
	
	$ad = get_theme_mod('vt_blogging_pro_ad_single_after');

	if ( get_theme_mod('vt_blogging_pro_ad_single_after', true) ) {
	  if ( is_single() ) {
		  
		$content = $content . '<div class="sponsor bot" itemscope itemtype="http://schema.org/WPAdBlock">
		<meta itemprop="name" content="Advertise Block" />
		<meta itemprop="description" content="Advertisement"/>
		' . $ad . '</div>';
		
	  } else {
		$content;
	  }
	}

	return $content;

}
add_action( 'the_content', 'vt_blogging_pro_single_ad_after' );

// Author Social Links
add_filter( 'user_contactmethods', 'vt_blogging_pro_author_social_links' );

function vt_blogging_pro_author_social_links() {
	
    $contactmethods              = array();
	$contactmethods['facebook']  = 'Facebook Username';
	$contactmethods['twitter']   = 'Twitter Username';
	$contactmethods['instagram'] = 'Instagram Username';
	$contactmethods['pinterest'] = 'Pinterest Username';
	$contactmethods['linkedin']  = 'Linkedin Username';
	$contactmethods['tumblr']    = 'Tumblr Username';
	$contactmethods['vk']    	 = 'VK Username';
	
	return $contactmethods;
}

// Add SoundCloud oEmbed
function add_oembed_soundcloud(){
	
	wp_oembed_add_provider( 'https://soundcloud.com/*', 'https://soundcloud.com/oembed' );
}
add_action('init','add_oembed_soundcloud');

/**
 * Header Code
 *
 * @since vt-blogging-pro 1.0
 */
if ( ! function_exists( 'vt_blogging_pro_apply_header' ) ) :
  	
  	function vt_blogging_pro_apply_header() {	
		if ( get_theme_mod('vt_blogging_pro_header_scripts') ) { 
		?>

		<script id="vt-blogging-pro-header-scripts"><?php echo get_theme_mod('vt_blogging_pro_header_scripts'); ?></script>
		
		<?php
    }
}
endif;
add_action('wp_head', 'vt_blogging_pro_apply_header');

/**
 * Footer Code
 *
 * @since vt-blogging-pro 1.0
 */
if ( ! function_exists( 'vt_blogging_pro_apply_footer' ) ) :
  	
  	function vt_blogging_pro_apply_footer() {	
		if ( get_theme_mod('vt_blogging_pro_footer_scripts') ) { 
		?>

		<script id="vt-blogging-pro-footer-scripts"><?php echo get_theme_mod('vt_blogging_pro_footer_scripts'); ?></script>
		
		<?php
    }
}
endif;
add_action('wp_footer', 'vt_blogging_pro_apply_footer');

// Scroll to top
function vt_blogging_pro_scroll_to_top() {
	if (get_theme_mod('backtotop-button', 1) == 1){
?>
	<div id="back-top">
		<a href="#top" title="<?php echo esc_attr('Back to top', 'vt-blogging-pro'); ?>"><span class="genericon genericon-collapse"></span></a>
	</div>
<?php
}}
add_action('wp_footer', 'vt_blogging_pro_scroll_to_top');
